==> react-markmirror-0.4.2.tgz: package/docs/toolbar.md <==
Toolbar Customizing
===================
React Markmirror includes a default toolbar with default buttons, but you can use your own toolbar by setting the `renderToolbar` prop.

This example adds a custom toolbar which only renders the bold and italic buttons.

```jsx
import React from 'react';
import Markmirror from 'react-markmirror';

class Editor extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      code: ''
    };
  }

  handleChange = (code) => {
    this.setState({ code });
  };

  /**
   * Removes every button from the toolbar except the bold and italic buttons
   * 
   * @param {Markmirror} markmirror   The object calling the function
   * @param {Function}   renderButton Renders the standard button for the given command
   * @param {Boolean}    showUpload   Whether the upload button should be displayed
   */
  renderToolbar = (markmirror, renderButton, showUpload) => (
    <div className="markmirror__toolbar myapp__toolbar">
      {renderButton('bold')}
      {renderButton('italic')}
    </div>
  );

  render() {
    return (
      <Markmirror
        value={this.state.code}
        onChange={this.handleChange}
        renderToolbar={this.renderToolbar}
      />
    );
  }
}
```


This next example adds a "Save" button to the toolbar. When clicked the button uses the [fetch API](https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API) to send the markdown code to a fictitious backend to be saved.

```jsx
import React from 'react';
import Markmirror from 'react-markmirror';

class Editor extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      code: ''
    };
  }

  handleChange = (code) => {
    this.setState({ code });
  };

  handleSave = () => {
    const form = new FormData();
    form.append('code', this.state.code);
    
    fetch('https://yoursite.com/save', {
      method: 'post',
      body: form
    }).then(() => {
      alert('Document saved!');
    });
  };

  /**
   * Adds a save button to the toolbar
   * 
   * @param {Markmirror} markmirror  The object calling the function
   * @param {Function}   renderButton Renders the standard button for the given command
   */
  renderToolbar = (markmirror, renderButton) => (
    <div className="markmirror__toolbar myapp__toolbar">
      {renderButton('h1')}
      {renderButton('h2')}
      {renderButton('h3')}
      {renderButton('bold')}
      {renderButton('italic')}
      {renderButton('oList')}
      {renderButton('uList')}
      {renderButton('quote')}
      {renderButton('link')}
      {renderButton('image')}
      {renderButton('full')}
      
      <button className="markmirror__button myapp__button" onClick={this.handleSave}>
        Save
      </button>
    </div>
  );

  render() {
    return (
      <Markmirror
        value={this.state.code}
        onChange={this.handleChange}
        renderToolbar={this.renderToolbar}
      />
    );
  }
}
```

==> react-markmirror-0.4.10.tgz: package/docs/toolbar.md <==
Toolbar Customizing
===================
React Markmirror includes a default toolbar with default buttons, but you can use your own toolbar by setting the `renderToolbar` prop.

This example adds a custom toolbar which only renders the bold and italic buttons.

```jsx
import React from 'react';
import Markmirror from 'react-markmirror';

class Editor extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      code: ''
    };
  }

  handleChange = (code) => {
    this.setState({ code });
  };

  /**
   * Removes every button from the toolbar except the bold and italic buttons
   * 
   * @param {Markmirror} markmirror     The object calling the function
   * @param {Function}   renderButton   Renders the standard button for the given command
   * @param {Boolean}    showUpload     Whether the upload button should be displayed
   * @param {Boolean}    showFullscreen Whether the fullscreen button should be displayed
   */
  renderToolbar = (markmirror, renderButton, showUpload, showFullscreen) => (
    <div className="markmirror__toolbar myapp__toolbar">
      {renderButton('bold')}
      {renderButton('italic')}
    </div>
  );

  render() {
    return (
      <Markmirror
        value={this.state.code}
        onChange={this.handleChange}
        renderToolbar={this.renderToolbar}
      />
    );
  }
}
```


This next example adds a "Save" button to the toolbar. When clicked the button uses the [fetch API](https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API) to send the markdown code to a fictitious backend to be saved.

```jsx
import React from 'react';
import Markmirror from 'react-markmirror';

class Editor extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      code: ''
    };
  }

  handleChange = (code) => {
    this.setState({ code });
  };

  handleSave = () => {
    const form = new FormData();
    form.append('code', this.state.code);
    
    fetch('https://yoursite.com/save', {
      method: 'post',
      body: form
    }).then(() => {
      alert('Document saved!');
    });
  };

  /**
   * Adds a save button to the toolbar
   * 
   * @param {Markmirror} markmirror  The object calling the function
   * @param {Function}   renderButton Renders the standard button for the given command
   */
  renderToolbar = (markmirror, renderButton) => (
    <div className="markmirror__toolbar myapp__toolbar">
      {renderButton('h1')}
      {renderButton('h2')}
      {renderButton('h3')}
      {renderButton('bold')}
      {renderButton('italic')}
      {renderButton('oList')}
      {renderButton('uList')}
      {renderButton('quote')}
      {renderButton('link')}
      {renderButton('image')}
      {renderButton('full')}
      
      <button className="markmirror__button myapp__button" onClick={this.handleSave}>
        Save
      </button>
    </div>
  );

  render() {
    return (
      <Markmirror
        value={this.state.code}
        onChange={this.handleChange}
        renderToolbar={this.renderToolbar}
      />
    );
  }
}
```
